@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "controller/search_db.h"
 #include "base/utils.h"
@@ -823,3 +810,25 @@ void SearchDb::getAllApp()
 {
     strlistApp = Utils::getSystemManualList();
 }
+
+void SearchDb::updateDb()
+{
+    //删除本地数据库
+    QString dbdir = QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/.local/share/deepin/deepin-manual/search.db" ;
+    QDir dir(dbdir);
+    if (!dir.exists()) {
+        qCritical() << __FUNCTION__ << "db path not exist!" << dbdir;
+    }
+
+    dir.remove(dbdir);
+    //重新加载数据库，创建新表
+    createTable();
+
+}
+
+void SearchDb::createTable()
+{
+    initDb();
+    initSearchTable();
+    initTimeTable();
+}
